@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Mikael Hallendal <micke@imendio.com>
  *          Martyn Russell <martyn@imendio.com>
@@ -31,13 +31,14 @@
 #include <gtk/gtk.h>
 
 #include <telepathy-glib/util.h>
-#include <libempathy/empathy-debug.h>
 
+#include <libempathy/empathy-utils.h>
 #include "empathy-contact-list-store.h"
 #include "empathy-ui-utils.h"
 #include "empathy-gtk-enum-types.h"
 
-#define DEBUG_DOMAIN "ContactListStore"
+#define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
+#include <libempathy/empathy-debug.h>
 
 /* Active users are those which have recently changed state
  * (e.g. online, offline or from normal to a busy state).
@@ -49,8 +50,7 @@
 /* Time in seconds after connecting which we wait before active users are enabled */
 #define ACTIVE_USER_WAIT_TO_ENABLE_TIME 5
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_CONTACT_LIST_STORE, EmpathyContactListStorePriv))
-
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyContactListStore)
 typedef struct {
 	EmpathyContactList         *list;
 	gboolean                    show_offline;
@@ -80,8 +80,6 @@ typedef struct {
 	gboolean                remove;
 } ShowActiveData;
 
-static void             empathy_contact_list_store_class_init         (EmpathyContactListStoreClass *klass);
-static void             empathy_contact_list_store_init               (EmpathyContactListStore      *list);
 static void             contact_list_store_finalize                  (GObject                       *object);
 static void             contact_list_store_get_property              (GObject                       *object,
 								      guint                          param_id,
@@ -163,7 +161,6 @@ enum {
 
 G_DEFINE_TYPE (EmpathyContactListStore, empathy_contact_list_store, GTK_TYPE_TREE_STORE);
 
-
 static gboolean
 contact_list_store_iface_setup (gpointer user_data)
 {
@@ -273,10 +270,10 @@ empathy_contact_list_store_class_init (EmpathyContactListStoreClass *klass)
 static void
 empathy_contact_list_store_init (EmpathyContactListStore *store)
 {
-	EmpathyContactListStorePriv *priv;
-
-	priv = GET_PRIV (store);
+	EmpathyContactListStorePriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (store,
+		EMPATHY_TYPE_CONTACT_LIST_STORE, EmpathyContactListStorePriv);
 
+	store->priv = priv;
 	priv->show_avatars = TRUE;
 	priv->show_groups = TRUE;
 	priv->inhibit_active = g_timeout_add_seconds (ACTIVE_USER_WAIT_TO_ENABLE_TIME,
@@ -710,7 +707,7 @@ empathy_contact_list_store_search_equal_func (GtkTreeModel *model,
 	name_folded = g_utf8_casefold (name, -1);
 	key_folded = g_utf8_casefold (key, -1);
 
-	if (name_folded && key_folded && 
+	if (name_folded && key_folded &&
 	    strstr (name_folded, key_folded)) {
 		ret = FALSE;
 	} else {
@@ -739,7 +736,8 @@ contact_list_store_setup (EmpathyContactListStore *store)
 					       G_TYPE_BOOLEAN,       /* Is active */
 					       G_TYPE_BOOLEAN,       /* Is online */
 					       G_TYPE_BOOLEAN,       /* Is separator */
-					       G_TYPE_BOOLEAN};      /* Can VoIP */
+					       G_TYPE_BOOLEAN,       /* Can make audio calls */
+					       G_TYPE_BOOLEAN};      /* Can make video calls */
 	
 	priv = GET_PRIV (store);
 
@@ -787,11 +785,10 @@ contact_list_store_members_changed_cb (EmpathyContactList      *list_iface,
 
 	priv = GET_PRIV (store);
 
-	empathy_debug (DEBUG_DOMAIN, 
-		      "Contact %s (%d) %s",
-		      empathy_contact_get_id (contact),
-		      empathy_contact_get_handle (contact),
-		      is_member ? "added" : "removed");
+	DEBUG ("Contact %s (%d) %s",
+		empathy_contact_get_id (contact),
+		empathy_contact_get_handle (contact),
+		is_member ? "added" : "removed");
 
 	if (is_member) {
 		g_signal_connect (contact, "notify::presence",
@@ -832,9 +829,9 @@ contact_list_store_groups_changed_cb (EmpathyContactList      *list_iface,
 
 	priv = GET_PRIV (store);
 
-	empathy_debug (DEBUG_DOMAIN, "Updating groups for contact %s (%d)",
-		      empathy_contact_get_id (contact),
-		      empathy_contact_get_handle (contact));
+	DEBUG ("Updating groups for contact %s (%d)",
+		empathy_contact_get_id (contact),
+		empathy_contact_get_handle (contact));
 
 	/* We do this to make sure the groups are correct, if not, we
 	 * would have to check the groups already set up for each
@@ -857,7 +854,7 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 
 	priv = GET_PRIV (store);
 	
-	if (G_STR_EMPTY (empathy_contact_get_name (contact)) ||
+	if (EMP_STR_EMPTY (empathy_contact_get_name (contact)) ||
 	    (!priv->show_offline && !empathy_contact_is_online (contact))) {
 		return;
 	}
@@ -874,7 +871,12 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 				    EMPATHY_CONTACT_LIST_STORE_COL_CONTACT, contact,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, FALSE,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_SEPARATOR, FALSE,
-				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VOIP, empathy_contact_can_voip (contact),
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_AUDIO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_AUDIO,
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VIDEO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_VIDEO,
 				    -1);
 	}
 
@@ -891,7 +893,12 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 				    EMPATHY_CONTACT_LIST_STORE_COL_CONTACT, contact,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, FALSE,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_SEPARATOR, FALSE,
-				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VOIP, empathy_contact_can_voip (contact),
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_AUDIO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_AUDIO,
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VIDEO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_VIDEO,
 				    -1);
 		g_free (l->data);
 	}
@@ -924,7 +931,7 @@ contact_list_store_remove_contact (EmpathyContactListStore *store,
 
 		/* NOTE: it is only <= 2 here because we have
 		 * separators after the group name, otherwise it
-		 * should be 1. 
+		 * should be 1.
 		 */
 		if (gtk_tree_model_iter_parent (model, &parent, l->data) &&
 		    gtk_tree_model_iter_n_children (model, &parent) <= 2) {
@@ -979,18 +986,16 @@ contact_list_store_contact_update (EmpathyContactListStore *store,
 
 	if (!in_list && !should_be_in_list) {
 		/* Nothing to do. */
-		empathy_debug (DEBUG_DOMAIN,
-			      "Contact:'%s' in list:NO, should be:NO",
-			      empathy_contact_get_name (contact));
+		DEBUG ("Contact:'%s' in list:NO, should be:NO",
+			empathy_contact_get_name (contact));
 
 		g_list_foreach (iters, (GFunc) gtk_tree_iter_free, NULL);
 		g_list_free (iters);
 		return;
 	}
 	else if (in_list && !should_be_in_list) {
-		empathy_debug (DEBUG_DOMAIN,
-			      "Contact:'%s' in list:YES, should be:NO",
-			      empathy_contact_get_name (contact));
+		DEBUG ("Contact:'%s' in list:YES, should be:NO",
+			empathy_contact_get_name (contact));
 
 		if (priv->show_active) {
 			do_remove = TRUE;
@@ -998,28 +1003,26 @@ contact_list_store_contact_update (EmpathyContactListStore *store,
 			do_set_refresh = TRUE;
 
 			set_model = TRUE;
-			empathy_debug (DEBUG_DOMAIN, "Remove item (after timeout)");
+			DEBUG ("Remove item (after timeout)");
 		} else {
-			empathy_debug (DEBUG_DOMAIN, "Remove item (now)!");
+			DEBUG ("Remove item (now)!");
 			contact_list_store_remove_contact (store, contact);
 		}
 	}
 	else if (!in_list && should_be_in_list) {
-		empathy_debug (DEBUG_DOMAIN,
-			      "Contact:'%s' in list:NO, should be:YES",
-			      empathy_contact_get_name (contact));
+		DEBUG ("Contact:'%s' in list:NO, should be:YES",
+			empathy_contact_get_name (contact));
 
 		contact_list_store_add_contact (store, contact);
 
 		if (priv->show_active) {
 			do_set_active = TRUE;
 
-			empathy_debug (DEBUG_DOMAIN, "Set active (contact added)");
+			DEBUG ("Set active (contact added)");
 		}
 	} else {
-		empathy_debug (DEBUG_DOMAIN,
-			      "Contact:'%s' in list:YES, should be:YES",
-			      empathy_contact_get_name (contact));
+		DEBUG ("Contact:'%s' in list:YES, should be:YES",
+			empathy_contact_get_name (contact));
 
 		/* Get online state before. */
 		if (iters && g_list_length (iters) > 0) {
@@ -1034,15 +1037,15 @@ contact_list_store_contact_update (EmpathyContactListStore *store,
 				do_set_active = TRUE;
 				do_set_refresh = TRUE;
 
-				empathy_debug (DEBUG_DOMAIN, "Set active (contact updated %s)",
-					      was_online ? "online  -> offline" :
-							   "offline -> online");
+				DEBUG ("Set active (contact updated %s)",
+					was_online ? "online  -> offline" :
+					"offline -> online");
 			} else {
 				/* Was TRUE for presence updates. */
 				/* do_set_active = FALSE;  */
 				do_set_refresh = TRUE;
 
-				empathy_debug (DEBUG_DOMAIN, "Set active (contact updated)");
+				DEBUG ("Set active (contact updated)");
 			}
 		}
 
@@ -1064,7 +1067,12 @@ contact_list_store_contact_update (EmpathyContactListStore *store,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_GROUP, FALSE,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_ONLINE, now_online,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_SEPARATOR, FALSE,
-				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VOIP, empathy_contact_can_voip (contact),
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_AUDIO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_AUDIO,
+				    EMPATHY_CONTACT_LIST_STORE_COL_CAN_VIDEO_CALL,
+				      empathy_contact_get_capabilities (contact) &
+				        EMPATHY_CAPABILITIES_VIDEO,
 				    -1);
 	}
 
@@ -1097,9 +1105,8 @@ contact_list_store_contact_updated_cb (EmpathyContact          *contact,
 				       GParamSpec              *param,
 				       EmpathyContactListStore *store)
 {
-	empathy_debug (DEBUG_DOMAIN,
-		      "Contact:'%s' updated, checking roster is in sync...",
-		      empathy_contact_get_name (contact));
+	DEBUG ("Contact:'%s' updated, checking roster is in sync...",
+		empathy_contact_get_name (contact));
 
 	contact_list_store_contact_update (store, contact);
 }
@@ -1125,7 +1132,7 @@ contact_list_store_contact_set_active (EmpathyContactListStore *store,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_ACTIVE, active,
 				    -1);
 
-		empathy_debug (DEBUG_DOMAIN, "Set item %s", active ? "active" : "inactive");
+		DEBUG ("Set item %s", active ? "active" : "inactive");
 
 		if (set_changed) {
 			path = gtk_tree_model_get_path (model, l->data);
@@ -1146,10 +1153,9 @@ contact_list_store_contact_active_new (EmpathyContactListStore *store,
 {
 	ShowActiveData *data;
 
-	empathy_debug (DEBUG_DOMAIN, 
-		      "Contact:'%s' now active, and %s be removed",
-		      empathy_contact_get_name (contact), 
-		      remove ? "WILL" : "WILL NOT");
+	DEBUG ("Contact:'%s' now active, and %s be removed",
+		empathy_contact_get_name (contact),
+		remove ? "WILL" : "WILL NOT");
 	
 	data = g_slice_new0 (ShowActiveData);
 
@@ -1179,15 +1185,13 @@ contact_list_store_contact_active_cb (ShowActiveData *data)
 	if (data->remove &&
 	    !priv->show_offline &&
 	    !empathy_contact_is_online (data->contact)) {
-		empathy_debug (DEBUG_DOMAIN, 
-			      "Contact:'%s' active timeout, removing item",
-			      empathy_contact_get_name (data->contact));
+		DEBUG ("Contact:'%s' active timeout, removing item",
+			empathy_contact_get_name (data->contact));
 		contact_list_store_remove_contact (data->store, data->contact);
 	}
 
-	empathy_debug (DEBUG_DOMAIN, 
-		      "Contact:'%s' no longer active",
-		      empathy_contact_get_name (data->contact));
+	DEBUG ("Contact:'%s' no longer active",
+		empathy_contact_get_name (data->contact));
 
 	contact_list_store_contact_set_active (data->store,
 					       data->contact,
@@ -1271,7 +1275,7 @@ contact_list_store_get_group (EmpathyContactListStore *store,
 		}
 
 		gtk_tree_store_append (GTK_TREE_STORE (store),
-				       &iter_separator, 
+				       &iter_separator,
 				       &iter_group);
 		gtk_tree_store_set (GTK_TREE_STORE (store), &iter_separator,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_SEPARATOR, TRUE,
