@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- * 
+ *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
@@ -62,9 +62,14 @@ empathy_contact_menu_new (EmpathyContact             *contact,
 		gtk_widget_show (item);
 	}
 
-	/* Call */
 	if (features & EMPATHY_CONTACT_FEATURE_CALL) {
-		item = empathy_contact_call_menu_item_new (contact);
+		/* Audio Call */
+		item = empathy_contact_audio_call_menu_item_new (contact);
+		gtk_menu_shell_append (shell, item);
+		gtk_widget_show (item);
+
+		/* Video Call */
+		item = empathy_contact_video_call_menu_item_new (contact);
 		gtk_menu_shell_append (shell, item);
 		gtk_widget_show (item);
 	}
@@ -141,24 +146,24 @@ empathy_contact_chat_menu_item_new (EmpathyContact *contact)
 }
 
 static void
-empathy_contact_call_menu_item_activated (GtkMenuItem *item,
+empathy_contact_audio_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
 	EmpathyCallFactory *factory;
 
 	factory = empathy_call_factory_get ();
-	empathy_call_factory_new_call (factory, contact);
+	empathy_call_factory_new_call_with_streams (factory, contact, TRUE, FALSE);
 }
 
 GtkWidget *
-empathy_contact_call_menu_item_new (EmpathyContact *contact)
+empathy_contact_audio_call_menu_item_new (EmpathyContact *contact)
 {
 	GtkWidget *item;
 	GtkWidget *image;
 
 	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Call"));
+	item = gtk_image_menu_item_new_with_mnemonic (C_("menu item", "_Audio Call"));
 	image = gtk_image_new_from_icon_name (EMPATHY_IMAGE_VOIP,
 					      GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -166,9 +171,41 @@ empathy_contact_call_menu_item_new (EmpathyContact *contact)
 	gtk_widget_show (image);
 
 	g_signal_connect (item, "activate",
-				  G_CALLBACK (empathy_contact_call_menu_item_activated),
+				  G_CALLBACK (empathy_contact_audio_call_menu_item_activated),
 				  contact);
-	
+
+	return item;
+}
+
+static void
+empathy_contact_video_call_menu_item_activated (GtkMenuItem *item,
+	EmpathyContact *contact)
+{
+	EmpathyCallFactory *factory;
+
+	factory = empathy_call_factory_get ();
+	empathy_call_factory_new_call_with_streams (factory, contact, TRUE, TRUE);
+}
+
+GtkWidget *
+empathy_contact_video_call_menu_item_new (EmpathyContact *contact)
+{
+	GtkWidget *item;
+	GtkWidget *image;
+
+	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
+
+	item = gtk_image_menu_item_new_with_mnemonic (C_("menu item", "_Video Call"));
+	image = gtk_image_new_from_icon_name (EMPATHY_IMAGE_VIDEO_CALL,
+					      GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+	gtk_widget_set_sensitive (item, empathy_contact_can_voip (contact));
+	gtk_widget_show (image);
+
+	g_signal_connect (item, "activate",
+				  G_CALLBACK (empathy_contact_video_call_menu_item_activated),
+				  contact);
+
 	return item;
 }
 
@@ -236,7 +273,7 @@ empathy_contact_file_transfer_menu_item_new (EmpathyContact *contact)
 static void
 contact_info_menu_item_activate_cb (EmpathyContact *contact)
 {
-	empathy_contact_information_dialog_show (contact, NULL, FALSE, FALSE);
+	empathy_contact_information_dialog_show (contact, NULL);
 }
 
 GtkWidget *
@@ -263,7 +300,7 @@ empathy_contact_info_menu_item_new (EmpathyContact *contact)
 static void
 contact_edit_menu_item_activate_cb (EmpathyContact *contact)
 {
-	empathy_contact_information_dialog_show (contact, NULL, TRUE, FALSE);
+	empathy_contact_edit_dialog_show (contact, NULL);
 }
 
 GtkWidget *
@@ -301,7 +338,6 @@ room_sub_menu_data_new (EmpathyContact *contact,
 	data = g_slice_new (RoomSubMenuData);
 	data->contact = g_object_ref (contact);
 	data->chatroom = g_object_ref (chatroom);
-
 	return data;
 }
 
@@ -360,9 +396,7 @@ empathy_contact_invite_menu_item_new (EmpathyContact *contact)
 	GtkWidget *room_item;
 	EmpathyChatroomManager *mgr;
 	GList *rooms, *l;
-	GtkWidget *submenu;
-	GtkMenuShell *submenu_shell;
-	gboolean have_rooms = FALSE;
+	GtkWidget *submenu = NULL;
 
 	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
@@ -375,27 +409,23 @@ empathy_contact_invite_menu_item_new (EmpathyContact *contact)
 	rooms = empathy_chatroom_manager_get_chatrooms (mgr,
 		empathy_contact_get_account (contact));
 
-	/* create rooms sub menu */
-	submenu = gtk_menu_new ();
-	submenu_shell = GTK_MENU_SHELL (submenu);
-
 	for (l = rooms; l != NULL; l = g_list_next (l)) {
 		EmpathyChatroom *chatroom = l->data;
 
 		if (empathy_chatroom_get_tp_chat (chatroom) != NULL) {
-			have_rooms = TRUE;
+			if (G_UNLIKELY (submenu == NULL))
+				submenu = gtk_menu_new ();
 
 			room_item = create_room_sub_menu (contact, chatroom);
-			gtk_menu_shell_append (submenu_shell, room_item);
+			gtk_menu_shell_append ((GtkMenuShell *) submenu, room_item);
 			gtk_widget_show (room_item);
 		}
 	}
 
-	if (have_rooms) {
+	if (submenu) {
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
 	} else {
 		gtk_widget_set_sensitive (item, FALSE);
-		gtk_widget_destroy (submenu);
 	}
 
 	gtk_widget_show (image);
