@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- * 
+ *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
@@ -31,7 +31,7 @@
 #include <libmissioncontrol/mc-enum-types.h>
 
 #include "empathy-idle.h"
-#include "empathy-utils.h" 
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include "empathy-debug.h"
@@ -53,6 +53,7 @@ typedef struct {
 
 	McPresence      away_saved_state;
 	McPresence      nm_saved_state;
+	gchar          *nm_saved_status;
 
 	gboolean        is_idle;
 	gboolean        nm_connected;
@@ -242,15 +243,23 @@ idle_nm_state_change_cb (DBusGProxy  *proxy,
 
 	if (old_nm_connected && !new_nm_connected) {
 		/* We are no more connected */
-		DEBUG ("Disconnected: Save state %d", priv->state);
+		DEBUG ("Disconnected: Save state %d (%s)",
+				priv->state, priv->status);
 		priv->nm_saved_state = priv->state;
+		g_free (priv->nm_saved_status);
+		priv->nm_saved_status = g_strdup (priv->status);
 		empathy_idle_set_state (idle, MC_PRESENCE_OFFLINE);
 	}
 	else if (!old_nm_connected && new_nm_connected) {
 		/* We are now connected */
-		DEBUG ("Reconnected: Restore state %d", priv->nm_saved_state);
-		empathy_idle_set_state (idle, priv->nm_saved_state);
+		DEBUG ("Reconnected: Restore state %d (%s)",
+				priv->nm_saved_state, priv->nm_saved_status);
+		empathy_idle_set_presence (idle,
+				priv->nm_saved_state,
+				priv->nm_saved_status);
 		priv->nm_saved_state = MC_PRESENCE_UNSET;
+		g_free (priv->nm_saved_status);
+		priv->nm_saved_status = NULL;
 	}
 
 	priv->nm_connected = new_nm_connected;
@@ -287,7 +296,7 @@ idle_constructor (GType type,
 			(type, n_props, props);
 
 		idle_singleton = EMPATHY_IDLE (retval);
-		g_object_add_weak_pointer (retval, (gpointer *) &idle_singleton);
+		g_object_add_weak_pointer (retval, (gpointer) &idle_singleton);
 	}
 
 	return retval;
