@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Mikael Hallendal <micke@imendio.com>
  *          Xavier Claessens <xclaesse@gmail.com>
@@ -75,6 +75,8 @@ const gchar *            empathy_message_type_to_str       (TpChannelTextMessage
 guint                    empathy_message_get_id (EmpathyMessage *message);
 void                     empathy_message_set_id (EmpathyMessage *message, guint id);
 
+gboolean                 empathy_message_equal (EmpathyMessage *message1, EmpathyMessage *message2);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_MESSAGE_H__ */
