@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #ifndef __EMPATHY_TIME_H__
@@ -36,8 +36,6 @@ G_BEGIN_DECLS
 time_t  empathy_time_get_current     (void);
 time_t  empathy_time_get_local_time  (struct tm   *tm);
 time_t  empathy_time_parse           (const gchar *str);
-time_t  empathy_time_parse_format    (const gchar *str,
-				      const gchar *format);
 gchar  *empathy_time_to_string_utc   (time_t       t,
 				      const gchar *format);
 gchar  *empathy_time_to_string_local (time_t       t,
