@@ -76,20 +76,12 @@ GType empathy_tp_call_get_type (void) G_GNUC_CONST;
 EmpathyTpCall *empathy_tp_call_new (TpChannel *channel);
 void empathy_tp_call_close (EmpathyTpCall *call);
 
-void empathy_tp_call_to (EmpathyTpCall *call, EmpathyContact *contact);
+void empathy_tp_call_to (EmpathyTpCall *call, EmpathyContact *contact,
+  gboolean audio, gboolean video);
 
 void empathy_tp_call_accept_incoming_call (EmpathyTpCall *call);
 void empathy_tp_call_request_video_stream_direction (EmpathyTpCall *call,
     gboolean is_sending);
-void empathy_tp_call_add_preview_video (EmpathyTpCall *call,
-    guint preview_video_socket_id);
-void empathy_tp_call_remove_preview_video (EmpathyTpCall *call,
-    guint preview_video_socket_id);
-void empathy_tp_call_add_output_video (EmpathyTpCall *call,
-    guint output_video_socket_id);
-void empathy_tp_call_set_output_volume (EmpathyTpCall *call, guint volume);
-void empathy_tp_call_mute_output (EmpathyTpCall *call, gboolean is_muted);
-void empathy_tp_call_mute_input (EmpathyTpCall *call, gboolean is_muted);
 void empathy_tp_call_start_tone (EmpathyTpCall *call, TpDTMFEvent event);
 void empathy_tp_call_stop_tone (EmpathyTpCall *call);
 gboolean empathy_tp_call_has_dtmf (EmpathyTpCall *call);
