@@ -15,9 +15,9 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- * 
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
  * Authors: Martyn Russell <martyn@imendio.com>
  *          Xavier Claessens <xclaesse@gmail.com>
  */
@@ -28,7 +28,6 @@
 #include <stdlib.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
@@ -218,9 +217,9 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 	profile = mc_account_get_profile (account);
 	config_ui = mc_profile_get_configuration_ui (profile);
 	if (!tp_strdiff (config_ui, "jabber")) {
-		dialog->settings_widget = 
+		dialog->settings_widget =
 			empathy_account_widget_jabber_new (account);
-	} 
+	}
 	else if (!tp_strdiff (config_ui, "msn")) {
 		dialog ->settings_widget =
 			empathy_account_widget_msn_new (account);
@@ -233,11 +232,11 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 		dialog->settings_widget =
 			empathy_account_widget_irc_new (account);
 	}
-	else if (!tp_strdiff(config_ui, "icq")) {
+	else if (!tp_strdiff (config_ui, "icq")) {
 		dialog->settings_widget =
 			empathy_account_widget_icq_new (account);
 	}
-	else if (!tp_strdiff(config_ui, "aim")) {
+	else if (!tp_strdiff (config_ui, "aim")) {
 		dialog->settings_widget =
 			empathy_account_widget_aim_new (account);
 	}
@@ -254,12 +253,13 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 			empathy_account_widget_groupwise_new (account);
 	}
 	else {
-		dialog->settings_widget = 
+		dialog->settings_widget =
 			empathy_account_widget_generic_new (account);
 	}
 
 	gtk_container_add (GTK_CONTAINER (dialog->alignment_settings),
 			   dialog->settings_widget);
+	gtk_widget_show (dialog->settings_widget);
 
 
 	gtk_image_set_from_icon_name (GTK_IMAGE (dialog->image_type),
@@ -358,7 +358,7 @@ accounts_dialog_enable_toggled_cb (GtkCellRendererToggle *cell_renderer,
 	mc_account_set_enabled (account, !enabled);
 
 	DEBUG ("%s account %s", enabled ? "Disabled" : "Enable",
-		mc_account_get_display_name(account));
+		mc_account_get_display_name (account));
 
 	g_object_unref (account);
 }
@@ -469,7 +469,7 @@ accounts_dialog_model_pixbuf_data_func (GtkTreeViewColumn    *tree_column,
 
 	if (pixbuf) {
 		if (status == TP_CONNECTION_STATUS_DISCONNECTED ||
-		    (status == TP_CONNECTION_STATUS_CONNECTING && 
+		    (status == TP_CONNECTION_STATUS_CONNECTING &&
 		     !dialog->connecting_show)) {
 			GdkPixbuf *modded_pixbuf;
 
@@ -658,7 +658,7 @@ accounts_dialog_account_added_cb (EmpathyAccountManager *manager,
 	 *    parameter for CM that have it. */
 	current_name = mc_account_get_display_name (account);
 	mc_account_get_param_string (account, "account", &account_param);
-	if (!G_STR_EMPTY (account_param)) {
+	if (!EMP_STR_EMPTY (account_param)) {
 		McProfile   *profile;
 		const gchar *profile_name;
 		gchar       *new_name;
@@ -819,10 +819,17 @@ accounts_dialog_button_create_clicked_cb (GtkWidget             *button,
 	gchar     *str;
 	McProfileCapabilityFlags cap;
 
-	profile = empathy_profile_chooser_get_selected (dialog->combobox_profile);
+	profile = empathy_profile_chooser_dup_selected (dialog->combobox_profile);
 
 	/* Create account */
 	account = mc_account_create (profile);
+	if (account == NULL) {
+		/* We can't display an error to the user as MC doesn't give us
+		 * any clue about the reason of the failure... */
+		g_object_unref (profile);
+		return;
+	}
+
 	/* To translator: %s is the protocol name */
 	str = g_strdup_printf (_("New %s account"),
 			       mc_profile_get_display_name (profile));
@@ -863,7 +870,7 @@ accounts_dialog_profile_changed_cb (GtkWidget             *widget,
 	McProfile *profile;
 	McProfileCapabilityFlags cap;
 
-	profile = empathy_profile_chooser_get_selected (dialog->combobox_profile);
+	profile = empathy_profile_chooser_dup_selected (dialog->combobox_profile);
 	cap = mc_profile_get_capabilities (profile);
 
 	if (cap & MC_PROFILE_CAPABILITY_REGISTRATION_UI) {
@@ -947,10 +954,10 @@ accounts_dialog_button_remove_clicked_cb (GtkWidget            *button,
 		   "they will still be available."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message_dialog),
-			       GTK_STOCK_CANCEL, 
+			       GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (message_dialog),
-			       GTK_STOCK_REMOVE, 
+			       GTK_STOCK_REMOVE,
 			       GTK_RESPONSE_YES);
 
 	gtk_widget_show (message_dialog);
@@ -1037,7 +1044,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 			      McAccount *selected_account)
 {
 	static EmpathyAccountsDialog *dialog = NULL;
-	GladeXML                     *glade;
+	GtkBuilder                   *gui;
 	gchar                        *filename;
 	GList                        *accounts, *l;
 	gboolean                      import_asked;
@@ -1049,11 +1056,9 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 
 	dialog = g_new0 (EmpathyAccountsDialog, 1);
 
-	filename = empathy_file_lookup ("empathy-accounts-dialog.glade",
+	filename = empathy_file_lookup ("empathy-accounts-dialog.ui",
 					"src");
-	glade = empathy_glade_get_file (filename,
-				       "accounts_dialog",
-				       NULL,
+	gui = empathy_builder_get_file (filename,
 				       "accounts_dialog", &dialog->window,
 				       "vbox_details", &dialog->vbox_details,
 				       "frame_no_profile", &dialog->frame_no_profile,
@@ -1072,8 +1077,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 				       NULL);
 	g_free (filename);
 
-	empathy_glade_connect (glade,
-			      dialog,
+	empathy_builder_connect (gui, dialog,
 			      "accounts_dialog", "destroy", accounts_dialog_destroy_cb,
 			      "accounts_dialog", "response", accounts_dialog_response_cb,
 			      "button_create", "clicked", accounts_dialog_button_create_clicked_cb,
@@ -1086,7 +1090,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 
 	g_object_add_weak_pointer (G_OBJECT (dialog->window), (gpointer) &dialog);
 
-	g_object_unref (glade);
+	g_object_unref (gui);
 
 	/* Create profile chooser */
 	dialog->combobox_profile = empathy_profile_chooser_new ();
@@ -1100,7 +1104,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 
 	/* Set up signalling */
 	dialog->account_manager = empathy_account_manager_dup_singleton ();
-	dialog->mc = empathy_mission_control_new ();
+	dialog->mc = empathy_mission_control_dup_singleton ();
 
 	g_signal_connect (dialog->account_manager, "account-created",
 			  G_CALLBACK (accounts_dialog_account_added_cb),
@@ -1147,11 +1151,17 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 	empathy_conf_get_bool (empathy_conf_get (),
 			       EMPATHY_PREFS_IMPORT_ASKED, &import_asked);
 
-	if (!import_asked) {
-		empathy_conf_set_bool (empathy_conf_get (),
-				       EMPATHY_PREFS_IMPORT_ASKED, TRUE);
-		empathy_import_dialog_show (GTK_WINDOW (dialog->window),
-					    FALSE);
+
+	if (empathy_import_dialog_accounts_to_import ()) {
+
+		if (!import_asked) {
+			empathy_conf_set_bool (empathy_conf_get (),
+					       EMPATHY_PREFS_IMPORT_ASKED, TRUE);
+			empathy_import_dialog_show (GTK_WINDOW (dialog->window),
+						    FALSE);
+		}
+	} else {
+		gtk_widget_set_sensitive (dialog->button_import, FALSE);
 	}
 
 	return dialog->window;
