@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  *
  * Authors: Jonny Lamb <jonny.lamb@collabora.co.uk>
  * */
@@ -294,7 +294,7 @@ empathy_import_pidgin_load (void)
     }
 
 OUT:
-  xmlFreeDoc(doc);
+  xmlFreeDoc (doc);
   xmlFreeParserCtxt (ctxt);
 
 FILENAME:
@@ -303,3 +303,19 @@ FILENAME:
   return accounts;
 }
 
+gboolean
+empathy_import_pidgin_accounts_to_import (void)
+{
+  gchar *filename;
+  gboolean out;
+  GFile *file;
+
+  filename = g_build_filename (g_get_home_dir (), ".purple", "accounts.xml", NULL);
+  file = g_file_new_for_path (filename);
+  out = g_file_query_exists (file, NULL);
+
+  g_free (filename);
+  g_object_unref (file);
+
+  return out;
+}
