@@ -30,6 +30,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <glib/gprintf.h>
 
 #include <libmissioncontrol/mission-control.h>
 #include <libmissioncontrol/mc-account.h>
@@ -66,7 +67,8 @@ typedef struct {
 	GtkWidget         *treeview;
 	GtkTreeModel      *model;
 	GtkWidget         *button_join;
-	GtkWidget         *button_close;
+	GtkWidget         *label_error_message;
+	GtkWidget         *viewport_error;
 } EmpathyNewChatroomDialog;
 
 enum {
@@ -98,6 +100,12 @@ static void     new_chatroom_dialog_new_room_cb                     (EmpathyTpRo
 static void     new_chatroom_dialog_listing_cb                      (EmpathyTpRoomlist        *room_list,
 								     gpointer                  unused,
 								     EmpathyNewChatroomDialog *dialog);
+static void     start_listing_error_cb                              (EmpathyTpRoomlist        *room_list,
+								     GError                   *error,
+								     EmpathyNewChatroomDialog *dialog);
+static void     stop_listing_error_cb                               (EmpathyTpRoomlist        *room_list,
+								     GError                   *error,
+								     EmpathyNewChatroomDialog *dialog);
 static void     new_chatroom_dialog_model_clear                     (EmpathyNewChatroomDialog *dialog);
 static void     new_chatroom_dialog_model_row_activated_cb          (GtkTreeView             *tree_view,
 								     GtkTreePath             *path,
@@ -117,6 +125,8 @@ static void     new_chatroom_dialog_expander_browse_activate_cb     (GtkWidget
 static gboolean new_chatroom_dialog_entry_server_focus_out_cb       (GtkWidget               *widget,
 								     GdkEventFocus           *event,
 								     EmpathyNewChatroomDialog *dialog);
+static void	new_chatroom_dialog_button_close_error_clicked_cb   (GtkButton                *button,
+								     EmpathyNewChatroomDialog *dialog);
 
 static EmpathyNewChatroomDialog *dialog_p = NULL;
 
@@ -147,6 +157,8 @@ empathy_new_chatroom_dialog_show (GtkWindow *parent)
 				       "treeview", &dialog->treeview,
 				       "button_join", &dialog->button_join,
 				       "expander_browse", &dialog->expander_browse,
+				       "label_error_message", &dialog->label_error_message,
+				       "viewport_error", &dialog->viewport_error,
 				       NULL);
 	g_free (filename);
 
@@ -158,6 +170,7 @@ empathy_new_chatroom_dialog_show (GtkWindow *parent)
 			      "entry_server", "focus-out-event", new_chatroom_dialog_entry_server_focus_out_cb,
 			      "entry_room", "changed", new_chatroom_dialog_entry_changed_cb,
 			      "expander_browse", "activate", new_chatroom_dialog_expander_browse_activate_cb,
+			      "button_close_error", "clicked", new_chatroom_dialog_button_close_error_clicked_cb,
 			      NULL);
 
 	g_object_unref (gui);
@@ -411,9 +424,17 @@ new_chatroom_dialog_account_changed_cb (GtkComboBox             *combobox,
 		g_signal_connect (dialog->room_list, "notify::is-listing",
 				  G_CALLBACK (new_chatroom_dialog_listing_cb),
 				  dialog);
+		g_signal_connect (dialog->room_list, "error::start",
+				  G_CALLBACK (start_listing_error_cb),
+				  dialog);
+		g_signal_connect (dialog->room_list, "error::stop",
+				  G_CALLBACK (stop_listing_error_cb),
+				  dialog);
 
 		expanded = gtk_expander_get_expanded (GTK_EXPANDER (dialog->expander_browse));
 		if (expanded) {
+			gtk_widget_hide (dialog->viewport_error);
+			gtk_widget_set_sensitive (dialog->treeview, TRUE);
 			new_chatroom_dialog_browse_start (dialog);
 		}
 
@@ -428,6 +449,13 @@ new_chatroom_dialog_account_changed_cb (GtkComboBox             *combobox,
 	g_object_unref (account);
 }
 
+static void
+new_chatroom_dialog_button_close_error_clicked_cb   (GtkButton                *button,
+						     EmpathyNewChatroomDialog *dialog)
+{
+	gtk_widget_hide (dialog->viewport_error);
+}
+
 static void
 new_chatroom_dialog_roomlist_destroy_cb (EmpathyTpRoomlist        *room_list,
 					 EmpathyNewChatroomDialog *dialog)
@@ -486,6 +514,26 @@ new_chatroom_dialog_new_room_cb (EmpathyTpRoomlist        *room_list,
 	g_free (tooltip);
 }
 
+static void
+start_listing_error_cb (EmpathyTpRoomlist        *room_list,
+			GError                   *error,
+			EmpathyNewChatroomDialog *dialog)
+{
+	gtk_label_set_text (GTK_LABEL (dialog->label_error_message), _("Could not start room listing"));
+	gtk_widget_show_all (dialog->viewport_error);
+	gtk_widget_set_sensitive (dialog->treeview, FALSE);
+}
+
+static void
+stop_listing_error_cb (EmpathyTpRoomlist        *room_list,
+		       GError                   *error,
+		       EmpathyNewChatroomDialog *dialog)
+{
+	gtk_label_set_text (GTK_LABEL (dialog->label_error_message), _("Could not stop room listing"));
+	gtk_widget_show_all (dialog->viewport_error);
+	gtk_widget_set_sensitive (dialog->treeview, FALSE);
+}
+
 static void
 new_chatroom_dialog_listing_cb (EmpathyTpRoomlist        *room_list,
 				gpointer                  unused,
@@ -622,6 +670,8 @@ new_chatroom_dialog_expander_browse_activate_cb (GtkWidget               *widget
 		new_chatroom_dialog_browse_stop (dialog);
 		gtk_window_set_resizable (GTK_WINDOW (dialog->window), FALSE);
 	} else {
+		gtk_widget_hide (dialog->viewport_error);
+		gtk_widget_set_sensitive (dialog->treeview, TRUE);
 		new_chatroom_dialog_browse_start (dialog);
 		gtk_window_set_resizable (GTK_WINDOW (dialog->window), TRUE);
 	}
