@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- * 
+ *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
@@ -24,9 +24,10 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <libnotify/notification.h>
+
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-account-manager.h>
@@ -41,6 +42,7 @@
 #include "empathy-status-icon.h"
 #include "empathy-preferences.h"
 #include "empathy-event-manager.h"
+#include "empathy-misc.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_DISPATCHER
 #include <libempathy/empathy-debug.h>
@@ -57,31 +59,131 @@ typedef struct {
 	guint                blink_timeout;
 	EmpathyEventManager *event_manager;
 	EmpathyEvent        *event;
+	NotifyNotification  *notification;
 
 	GtkWindow           *window;
+	GtkUIManager        *ui_manager;
 	GtkWidget           *popup_menu;
-	GtkWidget           *show_window_item;
-	GtkWidget           *message_item;
-	GtkWidget           *status_item;
+	GtkAction           *show_window_item;
+	GtkAction           *new_message_item;
+	GtkAction           *status_item;
 } EmpathyStatusIconPriv;
 
 G_DEFINE_TYPE (EmpathyStatusIcon, empathy_status_icon, G_TYPE_OBJECT);
 
+static gboolean
+activate_event (EmpathyEvent *event)
+{
+	empathy_event_activate (event);
+
+	return FALSE;
+}
+
+static void
+status_icon_notification_closed_cb (NotifyNotification *notification,
+				    EmpathyStatusIcon  *icon)
+{
+	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
+	EmpathyNotificationClosedReason reason = 0;
+
+#ifdef notify_notification_get_closed_reason
+	reason = notify_notification_get_closed_reason (notification);
+#endif
+	if (priv->notification) {
+		g_object_unref (priv->notification);
+		priv->notification = NULL;
+	}
+
+	if (!priv->event) {
+		return;
+	}
+
+	/* the notification has been closed by the user, see the
+	 * DesktopNotification spec.
+	 */
+	if (reason == EMPATHY_NOTIFICATION_CLOSED_DISMISSED) {
+		/* use an idle here, as this callback is called from a
+		 * DBus signal handler inside libnotify, and we might call
+		 * a *_run_* method when activating the event.
+		 */
+		g_idle_add ((GSourceFunc) activate_event, priv->event);
+	} else {
+		/* inhibit other updates for this event */
+		empathy_event_inhibit_updates (priv->event);
+	}
+}
+
+static void
+notification_close_helper (EmpathyStatusIconPriv *priv)
+{
+	if (priv->notification) {
+		notify_notification_close (priv->notification, NULL);
+		g_object_unref (priv->notification);
+		priv->notification = NULL;
+	}
+}
+
+static void
+status_icon_update_notification (EmpathyStatusIcon *icon)
+{
+	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
+	GdkPixbuf *pixbuf = NULL;
+
+	if (!empathy_notification_is_enabled ()) {
+		/* always close the notification if this happens */
+		notification_close_helper (priv);
+		return;
+	}
+
+	if (priv->event) {
+		pixbuf = empathy_misc_get_pixbuf_for_notification (priv->event->contact,
+								   priv->event->icon_name);
+
+		if (priv->notification) {
+			notify_notification_update (priv->notification,
+						    priv->event->header, priv->event->message,
+						    NULL);
+		} else {
+			priv->notification = notify_notification_new_with_status_icon
+				(priv->event->header, priv->event->message, NULL, priv->icon);
+			notify_notification_set_timeout (priv->notification,
+							 NOTIFY_EXPIRES_DEFAULT);
+
+			g_signal_connect (priv->notification, "closed",
+					  G_CALLBACK (status_icon_notification_closed_cb), icon);
+
+ 		}
+		notify_notification_set_icon_from_pixbuf (priv->notification,
+							  pixbuf);
+		notify_notification_show (priv->notification, NULL);
+
+		g_object_unref (pixbuf);
+	} else {
+		notification_close_helper (priv);
+	}
+}
+
 static void
 status_icon_update_tooltip (EmpathyStatusIcon *icon)
 {
 	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
-	const gchar           *tooltip = NULL;
+	gchar                 *tooltip = NULL;
 
 	if (priv->event) {
-		tooltip = priv->event->message;
+		if (priv->event->message != NULL)
+				tooltip = g_strdup_printf ("<i>%s</i>\n%s",
+							   priv->event->header,
+							   priv->event->message);
+		else
+				tooltip = g_strdup_printf ("<i>%s</i>",
+							   priv->event->header);
+		gtk_status_icon_set_tooltip_markup (priv->icon, tooltip);
+	} else {
+		tooltip = g_strdup (empathy_idle_get_status (priv->idle));
+		gtk_status_icon_set_tooltip_text (priv->icon, tooltip);
 	}
 
-	if (!tooltip) {
-		tooltip = empathy_idle_get_status (priv->idle);
-	}
-
-	gtk_status_icon_set_tooltip (priv->icon, tooltip);	
+	g_free (tooltip);
 }
 
 static void
@@ -112,7 +214,6 @@ status_icon_blink_timeout_cb (EmpathyStatusIcon *icon)
 
 	return TRUE;
 }
-
 static void
 status_icon_event_added_cb (EmpathyEventManager *manager,
 			    EmpathyEvent        *event,
@@ -131,6 +232,7 @@ status_icon_event_added_cb (EmpathyEventManager *manager,
 
 	status_icon_update_icon (icon);
 	status_icon_update_tooltip (icon);
+	status_icon_update_notification (icon);
 
 	if (!priv->blink_timeout) {
 		priv->blink_timeout = g_timeout_add (BLINK_TIMEOUT,
@@ -155,12 +257,35 @@ status_icon_event_removed_cb (EmpathyEventManager *manager,
 	status_icon_update_tooltip (icon);
 	status_icon_update_icon (icon);
 
+	/* update notification anyway, as it's safe and we might have been
+	 * changed presence in the meanwhile
+	 */	
+	status_icon_update_notification (icon);
+
 	if (!priv->event && priv->blink_timeout) {
 		g_source_remove (priv->blink_timeout);
 		priv->blink_timeout = 0;
 	}
 }
 
+static void
+status_icon_event_updated_cb (EmpathyEventManager *manager,
+			      EmpathyEvent        *event,
+			      EmpathyStatusIcon   *icon)
+{
+	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
+
+	if (event != priv->event) {
+		return;
+	}
+
+	if (empathy_notification_is_enabled ()) {
+		status_icon_update_notification (icon);
+	}
+
+	status_icon_update_tooltip (icon);
+}
+
 static void
 status_icon_set_visibility (EmpathyStatusIcon *icon,
 			    gboolean           visible,
@@ -217,8 +342,20 @@ status_icon_toggle_visibility (EmpathyStatusIcon *icon)
 static void
 status_icon_idle_notify_cb (EmpathyStatusIcon *icon)
 {
+	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
+
 	status_icon_update_icon (icon);
 	status_icon_update_tooltip (icon);
+
+	if (!empathy_notification_is_enabled ()) {
+		/* dismiss the outstanding notification if present */
+
+		if (priv->notification) {
+			notify_notification_close (priv->notification, NULL);
+			g_object_unref (priv->notification);
+			priv->notification = NULL;
+		}
+	}
 }
 
 static gboolean
@@ -257,24 +394,24 @@ status_icon_activate_cb (GtkStatusIcon     *status_icon,
 }
 
 static void
-status_icon_show_hide_window_cb (GtkWidget         *widget,
+status_icon_show_hide_window_cb (GtkToggleAction   *action,
 				 EmpathyStatusIcon *icon)
 {
 	gboolean visible;
 
-	visible = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget));
+	visible = gtk_toggle_action_get_active (action);
 	status_icon_set_visibility (icon, visible, TRUE);
 }
 
 static void
-status_icon_new_message_cb (GtkWidget         *widget,
+status_icon_new_message_cb (GtkAction         *action,
 			    EmpathyStatusIcon *icon)
 {
 	empathy_new_message_dialog_show (NULL);
 }
 
 static void
-status_icon_quit_cb (GtkWidget         *window,
+status_icon_quit_cb (GtkAction         *action,
 		     EmpathyStatusIcon *icon)
 {
 	gtk_main_quit ();
@@ -287,6 +424,7 @@ status_icon_popup_menu_cb (GtkStatusIcon     *status_icon,
 			   EmpathyStatusIcon *icon)
 {
 	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
+	GtkWidget             *menu_item;
 	GtkWidget             *submenu;
 	gboolean               show;
 
@@ -295,15 +433,15 @@ status_icon_popup_menu_cb (GtkStatusIcon     *status_icon,
 	g_signal_handlers_block_by_func (priv->show_window_item,
 					 status_icon_show_hide_window_cb,
 					 icon);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->show_window_item),
-					show);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (priv->show_window_item),
+				      show);
 	g_signal_handlers_unblock_by_func (priv->show_window_item,
 					   status_icon_show_hide_window_cb,
 					   icon);
 
+	menu_item = gtk_ui_manager_get_widget (priv->ui_manager, "/menu/status");
 	submenu = empathy_presence_chooser_create_menu ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (priv->status_item),
-				   submenu);
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), submenu);
 
 	gtk_menu_popup (GTK_MENU (priv->popup_menu),
 			NULL, NULL,
@@ -317,28 +455,27 @@ static void
 status_icon_create_menu (EmpathyStatusIcon *icon)
 {
 	EmpathyStatusIconPriv *priv = GET_PRIV (icon);
-	GladeXML              *glade;
+	GtkBuilder            *gui;
 	gchar                 *filename;
 
-	filename = empathy_file_lookup ("empathy-status-icon.glade", "src");
-	glade = empathy_glade_get_file (filename,
-				       "tray_menu",
-				       NULL,
-				       "tray_menu", &priv->popup_menu,
-				       "tray_show_list", &priv->show_window_item,
-				       "tray_new_message", &priv->message_item,
-				       "tray_status", &priv->status_item,
+	filename = empathy_file_lookup ("empathy-status-icon.ui", "src");
+	gui = empathy_builder_get_file (filename,
+					"ui_manager", &priv->ui_manager,
+					"menu", &priv->popup_menu,
+					"show_list", &priv->show_window_item,
+					"new_message", &priv->new_message_item,
+					"status", &priv->status_item,
 				       NULL);
 	g_free (filename);
 
-	empathy_glade_connect (glade,
-			      icon,
-			      "tray_show_list", "toggled", status_icon_show_hide_window_cb,
-			      "tray_new_message", "activate", status_icon_new_message_cb,
-			      "tray_quit", "activate", status_icon_quit_cb,
+	empathy_builder_connect (gui, icon,
+			      "show_list", "toggled", status_icon_show_hide_window_cb,
+			      "new_message", "activate", status_icon_new_message_cb,
+			      "quit", "activate", status_icon_quit_cb,
 			      NULL);
 
-	g_object_unref (glade);
+	g_object_ref (priv->ui_manager);
+	g_object_unref (gui);
 }
 
 static void
@@ -355,7 +492,7 @@ status_icon_connection_changed_cb (EmpathyAccountManager *manager,
 	/* Check for a connected account */
 	connected_accounts = empathy_account_manager_get_connected_accounts (manager);
 
-	gtk_widget_set_sensitive (priv->message_item, connected_accounts > 0);
+	gtk_action_set_sensitive (priv->new_message_item, connected_accounts > 0);
 }
 
 static void
@@ -371,10 +508,17 @@ status_icon_finalize (GObject *object)
 					      status_icon_connection_changed_cb,
 					      object);
 
+	if (priv->notification) {
+		notify_notification_close (priv->notification, NULL);
+		g_object_unref (priv->notification);
+		priv->notification = NULL;
+	}
+
 	g_object_unref (priv->icon);
 	g_object_unref (priv->idle);
 	g_object_unref (priv->account_manager);
 	g_object_unref (priv->event_manager);
+	g_object_unref (priv->ui_manager);
 }
 
 static void
@@ -396,8 +540,8 @@ empathy_status_icon_init (EmpathyStatusIcon *icon)
 	icon->priv = priv;
 	priv->icon = gtk_status_icon_new ();
 	priv->account_manager = empathy_account_manager_dup_singleton ();
-	priv->idle = empathy_idle_new ();
-	priv->event_manager = empathy_event_manager_new ();
+	priv->idle = empathy_idle_dup_singleton ();
+	priv->event_manager = empathy_event_manager_dup_singleton ();
 
 	g_signal_connect (priv->account_manager,
 			  "account-connection-changed",
@@ -421,6 +565,9 @@ empathy_status_icon_init (EmpathyStatusIcon *icon)
 	g_signal_connect (priv->event_manager, "event-removed",
 			  G_CALLBACK (status_icon_event_removed_cb),
 			  icon);
+	g_signal_connect (priv->event_manager, "event-updated",
+			  G_CALLBACK (status_icon_event_updated_cb),
+			  icon);
 	g_signal_connect (priv->icon, "activate",
 			  G_CALLBACK (status_icon_activate_cb),
 			  icon);
@@ -443,7 +590,7 @@ empathy_status_icon_new (GtkWindow *window, gboolean hide_contact_list)
 
 	priv->window = g_object_ref (window);
 
-	g_signal_connect (priv->window, "key-press-event",
+	g_signal_connect_after (priv->window, "key-press-event",
 			  G_CALLBACK (status_icon_key_press_event_cb),
 			  icon);
 
